<?php
/**
 * Lucks API file
 * Contains useful fonctions to use the API
 */


// Configuration of the API
define("LUCKS_CHECKOUT_API_ENTRY_POINT", "https://lucks.money/api-checkout.php");
define("LUCKS_STATUS_API_ENTRY_POINT", "https://lucks.money/api-status.php");


/**
 * Returns a transaction ID based to use in the Lucks button
 * 
 * @param string $apiKey
 *      Your checkout API key (or store key)
 * @param float $amount
 *      The amount of the transaction in Lucks (minimum 0.01)
 * @param string $returnURL
 *      The address to redirect the user to after the transaction
 * @param string $message
 *      The description of the transaction (optional, maximum 256 bytes)
 * 
 * @return string|int
 *      If the preparation of the transaction was successful, returns a string of 16 alphanumeric characters corresponding to the transaction identifier
 *      In case of error, returns an integer corresponding to the error code (see https://lucks.money/solutions/checkout/)
 *      The error -1 is returned in case of an internal error (not from the API)
 */
function lucksGetTransactionId($apiKey, $amount, $returnURL, $message="") {
    // Prepare the parameters
    $parameters = [
        "api_key" => $apiKey,
        "amount" => $amount,
        "return_url" => $returnURL,
        "message" => $message
    ];
    // Send the request the the API
    $apiResponse = @json_decode(lucksSendPostRequest(LUCKS_CHECKOUT_API_ENTRY_POINT, $parameters));
    // Check for error
    if ($apiResponse === FALSE || $apiResponse === NULL) {
        return -1;
    }
    // Return the value
    if ($apiResponse->code === 0) {
        return $apiResponse->data;
    }
    return $apiResponse->code;
}


/**
 * Return the status of a transaction
 * 
 * @param string $apiKey
 *      Your checkout API key (or store key)
 * @param string $transactionId
 *      The identifier of the transaction to verify
 * 
 * @return string
 *      "paid" if the transaction has been paid
 *      "pending" if the transaction is awaiting validation
 *      "rejected" if the transaction has been rejected
 *      "not-found" if the transaction cannot be fount (this code is also used if the transaction has expired) 
 *      "error" if an error occured (that does NOT mean the transaction has been rejected)
 */
function lucksGetTransactionStatus($apiKey, $transactionId) {
    // Prepare the parameters
    $parameters = [
        "api_key" => $apiKey,
        "id" => $transactionId
    ];
    // Send the request the the API
    $apiResponse = @json_decode(lucksSendPostRequest(LUCKS_STATUS_API_ENTRY_POINT, $parameters));
    // Check for error
    if ($apiResponse === FALSE || $apiResponse === NULL) {
        return "error";
    }
    // Return the value
    if ($apiResponse->code === 0) {
        return $apiResponse->data->status;
    } else if ($apiResponse->code === 11) {
        "not-found";
    }
    return "error";
}


/**
 * Send a POST request and get return the response
 * 
 * @param string $url
 *      The target URL
 * @param array $data
 *      The POST data to send
 * 
 * @return string|boolean
 *      The response from the server if success
 *      FALSE in case of error
 */
function lucksSendPostRequest($url, $data) {
    // use key 'http' even if we send the request to https
    $options = array(
        'http' => array(
            'header'  => "Content-type: application/x-www-form-urlencoded\r\n",
            'method'  => 'POST',
            'content' => http_build_query($data)
        )
    );
    $context  = @stream_context_create($options);
    $result = @file_get_contents($url, false, $context);
    if ($result === FALSE) {
        return FALSE;
    }
    return $result;
}